==> georepo-server-2.1.1.1-sources.jar: de/narimo/georepo/server/ui/ImportUI.java <==
package de.narimo.georepo.server.ui;

public class ImportUI {

    public static StringBuffer getLayerCreateForm(String importUrl) {
        StringBuffer s = new StringBuffer();
        s.append("</br><p><b>CREATE new layer</b></p>");
        s.append("<form action='" + importUrl + "' method='post'>");
        s.append("<br>New layer name: <input type=\"text\" name=\"layertitle\"></input>");
        s.append("<br>Remote file url: <input type=\"text\" name=\"remotecsvurl\"></input>");
        s.append("<br>CSV delimiter: <input type=\"text\" name=\"csvdelimiter\"></input>");
        s.append("<br>Column types: <input type=\"text\" name=\"columntypes\"></input>");
        s.append("<br>Decimal separator: <input type=\"text\" name=\"decimalsep\"></input>");
        s.append("<br>Thousands separator: <input type=\"text\" name=\"thousandssep\"></input>");
        s.append("<br>Name of longitude column: <input type=\"text\" name=\"lonname\"></input>");
        s.append("<br>Name of latitude column: <input type=\"text\" name=\"latname\"></input>");
        s.append("<br>File is APPROVED? (\"true\"): <input type=\"text\" name=\"approved\"></input>");
        s.append("<br>(Optional) Keep only rows where column: <input type=\"text\" name=\"keepRowColumnName\"></input>\n"
                + "equals value: <input type=\"text\" name=\"keepRowColumnValue\"></input>");
        s.append("</br>");
        s.append("[<button>CREATE LAYER</button>]");
        s.append("</form>");
        return s;
    }
}

==> georepo-server-2.8-sources.jar: de/narimo/georepo/server/ui/ImportUI.java <==
package de.narimo.georepo.server.ui;

public class ImportUI {

    @Deprecated
    public static StringBuffer getLayerCreateForm(String importUrl) {
        StringBuffer s = new StringBuffer();
        s.append("</br><p><b>CREATE new layer</b></p>");
        s.append("<form action='" + importUrl + "' method='post'>");
        s.append("<br>New layer name: <input type=\"text\" name=\"layertitle\"></input>");
        s.append("<br>Remote file url: <input type=\"text\" name=\"remotecsvurl\"></input>");
        s.append("<br>CSV delimiter: <input type=\"text\" name=\"csvdelimiter\"></input>");
        s.append("<br>Column types: <input type=\"text\" name=\"columntypes\"></input>");
        s.append("<br>Decimal separator: <input type=\"text\" name=\"decimalsep\"></input>");
        s.append("<br>Thousands separator: <input type=\"text\" name=\"thousandssep\"></input>");
        s.append("<br>Name of longitude column: <input type=\"text\" name=\"lonname\"></input>");
        s.append("<br>Name of latitude column: <input type=\"text\" name=\"latname\"></input>");
        s.append("<br>File is APPROVED? (\"true\"): <input type=\"text\" name=\"approved\"></input>");
        s.append(
                "<br>(Optional) Keep only rows where column: <input type=\"text\" name=\"keepRowColumnName\"></input>\n"
                        + "equals value: <input type=\"text\" name=\"keepRowColumnValue\"></input>");
        s.append("</br>");
        s.append("[<button>CREATE LAYER</button>]");
        s.append("</form>");
        return s;
    }
}
